@@ -175,8 +175,7 @@ def get_aligned_reads(in_bam, data):
     return 1.0 * align / total
 
 def downsample(in_bam, data, target_counts, work_dir=None):
-    """Downsample a BAM file to the specified number of target counts.
-    """
+    """Downsample a BAM file to the specified number of target counts."""
     index(in_bam, data["config"], check_timestamp=False)
     ds_pct = get_downsample_pct(in_bam, target_counts, data)
     if ds_pct:
@@ -249,13 +248,34 @@ def _get_maxcov_downsample(data):
                     return int(avg_cov * params["maxcov_downsample_multiplier"])
     return None
 
-
 def check_header(in_bam, rgnames, ref_file, config):
     """Ensure passed in BAM header matches reference file and read groups names.
     """
     _check_bam_contigs(in_bam, ref_file, config)
     _check_sample(in_bam, rgnames)
 
+def has_tags(in_bam, tags):
+    """
+    Checks the first 10,000 records in a BAM file for a set of tags.
+    Returns True if all the tags are seen at least once and False otherwise.
+    """
+    assert isinstance(tags, set), f"{tags} is not a set."
+    assert is_bam(in_bam), f"{in_bam} is not a BAM file."
+    MAX_ALIGNMENTS = 10000
+    with pysam.Samfile(in_bam, "rb") as bamfile:
+        alignments = 0
+        for read in bamfile.fetch(until_eof=True):
+            alignments += 1
+            if alignments > MAX_ALIGNMENTS:
+                return False
+            if not tags:
+                return True
+            tags_left = tags.copy()
+            for tag in tags_left:
+                if read.has_tag(tag):
+                    tags.remove(tag)
+    return False
+
 def _check_sample(in_bam, rgnames):
     """Ensure input sample name matches expected run group names.
     """
@@ -330,7 +350,6 @@ def is_bam(in_file):
     else:
         return False
 
-
 def is_sam(in_file):
     _, ext = os.path.splitext(in_file)
     if ext == ".sam":
@@ -374,7 +393,6 @@ def bam_to_sam(in_file, config):
                 % (str(num_cores), in_file, out_file)))
     return out_file
 
-
 def reheader(header, bam_file, config):
     samtools = config_utils.get_program("samtools", config)
     base, ext = os.path.splitext(bam_file)
@@ -383,7 +401,6 @@ def reheader(header, bam_file, config):
     do.run(cmd.format(**locals()), "Reheadering %s." % bam_file)
     return out_file
 
-
 def merge(bamfiles, out_bam, config):
     assert all(map(is_bam, bamfiles)), ("Not all of the files to merge are not BAM "
                                         "files: %s " % (bamfiles))
@@ -402,7 +419,6 @@ def merge(bamfiles, out_bam, config):
     index(out_bam, config)
     return out_bam
 
-
 def sort(in_bam, config, order="coordinate", out_dir=None, force=False):
     """Sort a BAM file, skipping if already present.
     """
@@ -430,11 +446,9 @@ def sort(in_bam, config, order="coordinate", out_dir=None, force=False):
                    (order, os.path.basename(in_bam), os.path.basename(sort_file)))
     return sort_file
 
-
 def bam_already_sorted(in_bam, config, order):
     return order == _get_sort_order(in_bam, config)
 
-
 def _get_sort_order(in_bam, config):
     for line in pysam.view("-H", in_bam).split("\r\n"):
         if line.startswith("@HD"):
@@ -600,3 +614,22 @@ def count_alignments(in_bam, data, filter=None):
     result = subprocess.run(cmd, shell=True, stdout=subprocess.PIPE,
                             stderr=subprocess.PIPE)
     return int(result.stdout.decode().strip())
+
+def has_nalignments(in_bam, n, data, filter=None):
+    """
+    does a BAM file has at least n alignments?
+    """
+    sambamba = config_utils.get_program("sambamba", dd.get_config(data))
+    num_cores = dd.get_num_cores(data)
+    if not filter:
+        filter_string = ""
+        message = f"Counting alignments in {in_bam}."
+    else:
+        filter_string = "--filter {filter}"
+        message = f"Counting alignments in {in_bam} matching {filter}."
+    cmd = f"{sambamba} view -f sam {filter_string} {in_bam} | head -{n} | wc -l"
+    logger.info(message)
+    result = subprocess.run(cmd, shell=True, stdout=subprocess.PIPE,
+                            stderr=subprocess.PIPE)
+    return int(result.stdout.decode().strip()) >= n
+
