@@ -15,13 +15,13 @@ def picard_rnaseq_metrics(picard, align_bam, ref, ribo="null", out_file=None):
     if not file_exists(out_file):
         with tx_tmpdir(picard._config) as tmp_dir:
             with file_transaction(picard._config, out_file) as tx_out_file:
-                opts = [("INPUT", align_bam),
-                        ("OUTPUT", tx_out_file),
-                        ("TMP_DIR", tmp_dir),
-                        ("REF_FLAT", ref),
-                        ("STRAND_SPECIFICITY", "NONE"),
-                        ("ASSUME_SORTED", "True"),
-                        ("RIBOSOMAL_INTERVALS", ribo)]
+                opts = [("--INPUT", align_bam),
+                        ("--OUTPUT", tx_out_file),
+                        ("--TMP_DIR", tmp_dir),
+                        ("--REF_FLAT", ref),
+                        ("--STRAND_SPECIFICITY", "NONE"),
+                        ("--ASSUME_SORTED", "True"),
+                        ("--RIBOSOMAL_INTERVALS", ribo)]
 
                 picard.run("CollectRnaSeqMetrics", opts)
     return out_file
@@ -35,10 +35,10 @@ def picard_insert_metrics(picard, align_bam, out_file=None):
     if not file_exists(out_file):
         with tx_tmpdir(picard._config) as tmp_dir:
             with file_transaction(picard._config, out_file) as tx_out_file:
-                opts = [("INPUT", align_bam),
-                        ("OUTPUT", tx_out_file),
-                        ("HISTOGRAM_FILE", histogram),
-                        ("TMP_DIR", tmp_dir)]
+                opts = [("--INPUT", align_bam),
+                        ("--OUTPUT", tx_out_file),
+                        ("--Histogram_FILE", histogram),
+                        ("--TMP_DIR", tmp_dir)]
                 picard.run("CollectInsertSizeMetrics", opts)
     return out_file
 
@@ -53,12 +53,12 @@ def picard_sort(picard, align_bam, sort_order="coordinate",
     if not file_exists(out_file):
         with tx_tmpdir(picard._config) as tmp_dir:
             with file_transaction(picard._config, out_file) as tx_out_file:
-                opts = [("INPUT", align_bam),
-                        ("OUTPUT", out_file if pipe else tx_out_file),
-                        ("TMP_DIR", tmp_dir),
-                        ("SORT_ORDER", sort_order)]
+                opts = [("--INPUT", align_bam),
+                        ("--OUTPUT", out_file if pipe else tx_out_file),
+                        ("--TMP_DIR", tmp_dir),
+                        ("--SORT_ORDER", sort_order)]
                 if compression_level:
-                    opts.append(("COMPRESSION_LEVEL", compression_level))
+                    opts.append(("--COMPRESSION_LEVEL", compression_level))
                 picard.run("SortSam", opts, pipe=pipe)
     return out_file
 
@@ -71,14 +71,14 @@ def picard_merge(picard, in_files, out_file=None,
     if not file_exists(out_file):
         with tx_tmpdir(picard._config) as tmp_dir:
             with file_transaction(picard._config, out_file) as tx_out_file:
-                opts = [("OUTPUT", tx_out_file),
-                        ("SORT_ORDER", "coordinate"),
-                        ("MERGE_SEQUENCE_DICTIONARIES",
+                opts = [("--OUTPUT", tx_out_file),
+                        ("--SORT_ORDER", "coordinate"),
+                        ("--MERGE_SEQUENCE_DICTIONARIES",
                          "true" if merge_seq_dicts else "false"),
-                        ("USE_THREADING", "true"),
-                        ("TMP_DIR", tmp_dir)]
+                        ("--USE_THREADING", "true"),
+                        ("--TMP_DIR", tmp_dir)]
                 for in_file in in_files:
-                    opts.append(("INPUT", in_file))
+                    opts.append(("--INPUT", in_file))
                 picard.run("MergeSamFiles", opts)
     return out_file
 
@@ -99,11 +99,11 @@ def picard_reorder(picard, in_bam, ref_file, out_file):
         with tx_tmpdir(picard._config) as tmp_dir:
             with file_transaction(picard._config, out_file) as tx_out_file:
                 dict_file = "%s.dict" % os.path.splitext(ref_file)[0]
-                opts = [("INPUT", in_bam),
-                        ("OUTPUT", tx_out_file),
-                        ("SEQUENCE_DICTIONARY", dict_file),
-                        ("ALLOW_INCOMPLETE_DICT_CONCORDANCE", "true"),
-                        ("TMP_DIR", tmp_dir)]
+                opts = [("--INPUT", in_bam),
+                        ("--OUTPUT", tx_out_file),
+                        ("--SEQUENCE_DICTIONARY", dict_file),
+                        ("--ALLOW_INCOMPLETE_DICT_CONCORDANCE", "true"),
+                        ("--TMP_DIR", tmp_dir)]
                 picard.run("ReorderSam", opts)
     return out_file
 
@@ -114,15 +114,15 @@ def picard_fix_rgs(picard, in_bam, names):
     if not file_exists(out_file):
         with tx_tmpdir(picard._config) as tmp_dir:
             with file_transaction(picard._config, out_file) as tx_out_file:
-                opts = [("INPUT", in_bam),
-                        ("OUTPUT", tx_out_file),
-                        ("SORT_ORDER", "coordinate"),
-                        ("RGID", names["rg"]),
-                        ("RGLB", names.get("lb", "unknown")),
-                        ("RGPL", names["pl"]),
-                        ("RGPU", names["pu"]),
-                        ("RGSM", names["sample"]),
-                        ("TMP_DIR", tmp_dir)]
+                opts = [("--INPUT", in_bam),
+                        ("--OUTPUT", tx_out_file),
+                        ("--SORT_ORDER", "coordinate"),
+                        ("--RGID", names["rg"]),
+                        ("--RGLB", names.get("lb", "unknown")),
+                        ("--RGPL", names["pl"]),
+                        ("--RGPU", names["pu"]),
+                        ("--RGSM", names["sample"]),
+                        ("--TMP_DIR", tmp_dir)]
                 picard.run("AddOrReplaceReadGroups", opts)
     return out_file
 
@@ -131,12 +131,12 @@ def picard_downsample(picard, in_bam, ds_pct, random_seed=None):
     if not file_exists(out_file):
         with tx_tmpdir(picard._config) as tmp_dir:
             with file_transaction(picard._config, out_file) as tx_out_file:
-                opts = [("INPUT", in_bam),
-                        ("OUTPUT", tx_out_file),
-                        ("PROBABILITY", "%.3f" % ds_pct),
-                        ("TMP_DIR", tmp_dir)]
+                opts = [("--INPUT", in_bam),
+                        ("--OUTPUT", tx_out_file),
+                        ("--PROBABILITY", "%.3f" % ds_pct),
+                        ("--TMP_DIR", tmp_dir)]
                 if random_seed:
-                    opts += [("RANDOM_SEED", str(random_seed))]
+                    opts += [("--RANDOM_SEED", str(random_seed))]
                 picard.run("DownsampleSam", opts)
     return out_file
 
@@ -146,8 +146,8 @@ def picard_index_ref(picard, ref_file):
     dict_file = "%s.dict" % os.path.splitext(ref_file)[0]
     if not file_exists(dict_file):
         with file_transaction(picard._config, dict_file) as tx_dict_file:
-            opts = [("REFERENCE", ref_file),
-                    ("OUTPUT", tx_dict_file)]
+            opts = [("--REFERENCE", ref_file),
+                    ("--OUTPUT", tx_dict_file)]
             picard.run("CreateSequenceDictionary", opts)
     return dict_file
 
@@ -159,16 +159,16 @@ def picard_fastq_to_bam(picard, fastq_one, fastq_two, out_dir, names, order="que
     if not file_exists(out_bam):
         with tx_tmpdir(picard._config) as tmp_dir:
             with file_transaction(picard._config, out_bam) as tx_out_bam:
-                opts = [("FASTQ", fastq_one),
-                        ("READ_GROUP_NAME", names["rg"]),
-                        ("SAMPLE_NAME", names["sample"]),
-                        ("PLATFORM_UNIT", names["pu"]),
-                        ("PLATFORM", names["pl"]),
-                        ("TMP_DIR", tmp_dir),
-                        ("OUTPUT", tx_out_bam),
-                        ("SORT_ORDER", order)]
+                opts = [("--FASTQ", fastq_one),
+                        ("--READ_GROUP_NAME", names["rg"]),
+                        ("--SAMPLE_NAME", names["sample"]),
+                        ("--PLATFORM_UNIT", names["pu"]),
+                        ("--PLATFORM", names["pl"]),
+                        ("--TMP_DIR", tmp_dir),
+                        ("--OUTPUT", tx_out_bam),
+                        ("--SORT_ORDER", order)]
                 if fastq_two:
-                    opts.append(("FASTQ2", fastq_two))
+                    opts.append(("--FASTQ2", fastq_two))
                 picard.run("FastqToSam", opts)
     return out_bam
 
@@ -178,11 +178,11 @@ def picard_bam_to_fastq(picard, in_bam, fastq_one, fastq_two=None):
     if not file_exists(fastq_one):
         with tx_tmpdir(picard._config) as tmp_dir:
             with file_transaction(picard._config, fastq_one) as tx_out1:
-                opts = [("INPUT", in_bam),
-                        ("FASTQ", tx_out1),
-                        ("TMP_DIR", tmp_dir)]
+                opts = [("--INPUT", in_bam),
+                        ("--FASTQ", tx_out1),
+                        ("--TMP_DIR", tmp_dir)]
                 if fastq_two is not None:
-                    opts += [("SECOND_END_FASTQ", fastq_two)]
+                    opts += [("--SECOND_END_FASTQ", fastq_two)]
                 picard.run("SamToFastq", opts)
     return (fastq_one, fastq_two)
 
@@ -200,14 +200,14 @@ def picard_sam_to_bam(picard, align_sam, fastq_bam, ref_file,
     if not file_exists(out_bam):
         with tx_tmpdir(picard._config) as tmp_dir:
             with file_transaction(picard._config, out_bam) as tx_out_bam:
-                opts = [("UNMAPPED", fastq_bam),
-                        ("ALIGNED", align_sam),
-                        ("OUTPUT", tx_out_bam),
-                        ("REFERENCE_SEQUENCE", ref_file),
-                        ("TMP_DIR", tmp_dir),
-                        ("PAIRED_RUN", ("true" if is_paired else "false")),
+                opts = [("--UNMAPPED", fastq_bam),
+                        ("--ALIGNED", align_sam),
+                        ("--OUTPUT", tx_out_bam),
+                        ("--REFERENCE_SEQUENCE", ref_file),
+                        ("--TMP_DIR", tmp_dir),
+                        ("--PAIRED_RUN", ("true" if is_paired else "false")),
                         ]
-                opts += [("ATTRIBUTES_TO_RETAIN", x) for x in to_retain]
+                opts += [("--ATTRIBUTES_TO_RETAIN", x) for x in to_retain]
                 picard.run("MergeBamAlignment", opts)
     return out_bam
 
@@ -218,9 +218,9 @@ def picard_formatconverter(picard, align_sam):
     if not file_exists(out_bam):
         with tx_tmpdir(picard._config) as tmp_dir:
             with file_transaction(picard._config, out_bam) as tx_out_bam:
-                opts = [("INPUT", align_sam),
-                        ("OUTPUT", tx_out_bam),
-                        ("TMP_DIR", tmp_dir)]
+                opts = [("--INPUT", align_sam),
+                        ("--OUTPUT", tx_out_bam),
+                        ("--TMP_DIR", tmp_dir)]
                 picard.run("SamFormatConverter", opts)
     return out_bam
 
@@ -232,13 +232,13 @@ def picard_mark_duplicates(picard, align_bam, remove_dups=False):
     if not file_exists(dup_bam):
         with tx_tmpdir(picard._config) as tmp_dir:
             with file_transaction(picard._config, dup_bam, dup_metrics) as (tx_dup_bam, tx_dup_metrics):
-                opts = [("INPUT", align_bam),
-                        ("OUTPUT", tx_dup_bam),
-                        ("TMP_DIR", tmp_dir),
-                        ("REMOVE_DUPLICATES", "true" if remove_dups else "false"),
-                        ("METRICS_FILE", tx_dup_metrics)]
+                opts = [("--INPUT", align_bam),
+                        ("--OUTPUT", tx_dup_bam),
+                        ("--TMP_DIR", tmp_dir),
+                        ("--REMOVE_DUPLICATES", "true" if remove_dups else "false"),
+                        ("--METRICS_FILE", tx_dup_metrics)]
                 if picard.get_picard_version("MarkDuplicates") >= 1.82:
-                    opts += [("PROGRAM_RECORD_ID", "null")]
+                    opts += [("--PROGRAM_RECORD_ID", "null")]
                 picard.run("MarkDuplicates", opts, memscale={"direction": "decrease", "magnitude": 2})
     return dup_bam, dup_metrics
 
@@ -250,10 +250,10 @@ def picard_fixmate(picard, align_bam):
     if not file_exists(out_file):
         with tx_tmpdir(picard._config) as tmp_dir:
             with file_transaction(picard._config, out_file) as tx_out_file:
-                opts = [("INPUT", align_bam),
-                        ("OUTPUT", tx_out_file),
-                        ("TMP_DIR", tmp_dir),
-                        ("SORT_ORDER", "coordinate")]
+                opts = [("--INPUT", align_bam),
+                        ("--OUTPUT", tx_out_file),
+                        ("--TMP_DIR", tmp_dir),
+                        ("--SORT_ORDER", "coordinate")]
                 picard.run("FixMateInformation", opts)
     return out_file
 
