@@ -99,12 +99,13 @@ def _alignment(checkpoints):
                                cwlout(["config", "algorithm", "quality_format"], ["string", "null"]),
                                cwlout(["align_split"], ["string", "null"])])],
                "bcbio-vc", ["grabix", "htslib", "biobambam", "atropos;env=python3",
-                            "optitype", "razers3=3.5.0", "coincbc"],  # HLA deps for general docker inclusion
+                            "optitype;env=python2", "razers3=3.5.0", "coincbc"],  # HLA deps for general docker inclusion
                disk={"files": 1.5}),
              s("process_alignment", "single-parallel" if checkpoints["align_split"] else "single-single",
                [["alignment_rec"], ["process_alignment_rec"]], process_alignment_out,
                "bcbio-vc", ["bwa", "bwakit", "grabix", "minimap2", "novoalign", "snap-aligner=1.0dev.97",
-                            "sentieon", "samtools", "pysam>=0.13.0", "sambamba", "fgbio", "umis",
+                            "sentieon;env=python2", "samtools", "pysam>=0.13.0", "sambamba", "fgbio",
+                            "umis;env=python2",
                             "biobambam", "seqtk", "samblaster", "variantbam"],
                disk={"files": 2})]
     if checkpoints["align_split"]:
@@ -138,7 +139,7 @@ def _variant_hla(checkpoints):
              [["hla_rec"]],
              [cwlout(["hla", "hlacaller"], ["string", "null"]),
               cwlout(["hla", "call_file"], ["File", "null"])],
-             "bcbio-vc", ["optitype", "razers3=3.5.0", "coincbc"])]
+             "bcbio-vc", ["optitype;env=python2", "razers3=3.5.0", "coincbc"])]
     return hla, [["hla", "call_file"]]
 
 def _variant_vc(checkpoints):
@@ -156,10 +157,10 @@ def _variant_vc(checkpoints):
                [cwlout(["vrn_file_region"], ["File", "null"], [".tbi"]),
                 cwlout(["region_block"], {"type": "array", "items": "string"})],
                "bcbio-vc", ["bcftools", "bedtools", "freebayes=1.1.0.46",
-                            "gatk4", "vqsr_cnn", "deepvariant", "sentieon",
-                            "htslib", "octopus", "picard", "platypus-variant", "pythonpy",
-                            "samtools", "pysam>=0.13.0", "strelka", "vardict", "vardict-java",
-                            "varscan", "moreutils", "vcfanno", "vcflib", "vt", "r=3.4.1", "r-base=3.4.1=h4fe35fd_8",
+                            "gatk4", "vqsr_cnn", "deepvariant;env=dv", "sentieon;env=python2",
+                            "htslib", "octopus", "picard", "platypus-variant;env=python2", "pythonpy",
+                            "samtools", "pysam>=0.13.0", "strelka;env=python2", "vardict", "vardict-java",
+                            "varscan", "moreutils", "vcfanno", "vcflib", "vt", "r=3.5.1", "r-base",
                             "perl"],
                disk={"files": 2.0}),
              s("concat_batch_variantcalls", "batch-merge",
@@ -184,7 +185,7 @@ def _variant_vc(checkpoints):
                                 cwlout(["validate", "fp"], ["File", "null"], [".tbi"]),
                                 cwlout(["validate", "fn"], ["File", "null"], [".tbi"]),
                                 cwlout("inherit", exclude=vc_rec_exclude)])],
-                "bcbio-vc", ["bcftools", "bedtools", "pythonpy", "gvcf-regions",
+                "bcbio-vc", ["bcftools", "bedtools", "pythonpy", "gvcf-regions;env=python2",
                              "htslib", "rtg-tools", "vcfanno"],
                 disk={"files": 1.5})]
     batch_in = [["analysis"], ["genome_build"], ["align_bam"], ["vrn_file"],
@@ -221,7 +222,9 @@ def _variant_vc(checkpoints):
         batch_in += [["genome_resources", "variation", "train_hapmap"],
                      ["genome_resources", "variation", "train_indels"]]
     vc = [s("batch_for_variantcall", "multi-batch", batch_in,
-            [cwlout("batch_rec", "record")],
+            [cwlout("batch_rec", "record",
+                    fields=[cwlout(["config", "algorithm", "variantcaller_order"], "int"),
+                            cwlout("inherit")])],
             "bcbio-vc",
             disk={"files": 2.0}, cores=1,
             unlist=[["config", "algorithm", "variantcaller"]], no_files=True),
@@ -273,7 +276,7 @@ def _variant_jointvc():
           s("run_jointvc", "batch-parallel",
             [["jointvc_batch_rec"], ["region"]],
             [cwlout(["vrn_file_region"], ["File", "null"], [".tbi"]), cwlout(["region"], "string")],
-            "bcbio-vc", ["gatk4", "gvcfgenotyper", "sentieon"],
+            "bcbio-vc", ["gatk4", "gvcfgenotyper", "sentieon;env=python2"],
             disk={"files": 1.5}, cores=1),
           s("concat_batch_variantcalls_jointvc", "batch-merge",
             [["jointvc_batch_rec"], ["region"], ["vrn_file_region"]],
@@ -387,7 +390,7 @@ def _postprocess_alignment(checkpoints):
              cwlout(["depth", "coverage", "dist"], ["File", "null"]),
              cwlout(["depth", "coverage", "thresholds"], ["File", "null"]),
              cwlout(["align_bam"], ["File", "null"])],
-            "bcbio-vc", ["sambamba", "goleft", "bedtools", "htslib", "gatk4", "mosdepth", "sentieon"],
+            "bcbio-vc", ["sambamba", "goleft", "bedtools", "htslib", "gatk4", "mosdepth", "sentieon;env=python2"],
             disk={"files": 3.0}),
           s("combine_sample_regions", "multi-combined",
             [["regions", "callable"], ["regions", "nblock"], ["metadata", "batch"],
@@ -440,7 +443,7 @@ def variant(samples):
     else:
         align = [s("organize_noalign", "multi-parallel",
                    ["files"],
-                   [cwlout(["align_bam"], "File", [".bai"]),
+                   [cwlout(["align_bam"], ["File", "null"], [".bai"]),
                     cwlout(["work_bam_plus", "disc"], ["File", "null"]),
                     cwlout(["work_bam_plus", "sr"], ["File", "null"]),
                     cwlout(["hla", "fastq"], ["File", "null"])],
@@ -492,7 +495,7 @@ def _qc_workflow(checkpoints):
                             cwlout(["config", "algorithm", "qc"])])],
             "bcbio-vc", ["bcftools", "bedtools", "fastqc=0.11.7=5", "goleft", "hts-nim-tools", "mosdepth",
                          "picard", "pythonpy", "qsignature", "qualimap", "sambamba",
-                         "samtools", "preseq", "peddy", "verifybamid2"],
+                         "samtools", "preseq", "peddy;env=python2", "verifybamid2"],
             disk={"files": 2.0}),
           s("multiqc_summary", "multi-combined",
             [["qcout_rec"]],
@@ -519,11 +522,12 @@ def _variant_sv(checkpoints):
                             cwlout(["svvalidate", "summary"], ["File", "null"]),
                             cwlout("inherit", exclude=[["align_bam"], ["work_bam_plus"],
                                                        ["reference", "snpeff"]])])],
-            "bcbio-vc", ["bedtools", "cnvkit", "delly", "duphold", "extract-sv-reads",
-                         "lumpy-sv", "manta", "break-point-inspector", "mosdepth", "samtools",
-                         "smoove", "pysam>=0.13.0",
-                         "seq2c", "simple_sv_annotation", "survivor", "svtools", "svtyper",
-                         "r=3.4.1", "r-base=3.4.1=h4fe35fd_8", "xorg-libxt", "vawk"],
+            "bcbio-vc", ["bedtools", "cnvkit", "delly", "duphold", "extract-sv-reads", "gsort",
+                         "lumpy-sv;env=python2", "manta;env=python2", "break-point-inspector", "mosdepth", "samtools",
+                         "smoove;env=python2", "pysam>=0.13.0",
+                         "seq2c", "simple_sv_annotation;env=python2", "survivor", "svtools;env=python2",
+                         "svtyper;env=python2",
+                         "r=3.5.1", "r-base", "xorg-libxt", "vawk;env=python2"],
             disk={"files": 2.0})]
     sv_batch_inputs = [["analysis"], ["genome_build"],
                        ["work_bam_plus", "disc"], ["work_bam_plus", "sr"],
@@ -619,7 +623,7 @@ def rnaseq(samples):
     align = [s("process_alignment", "multi-parallel",
                [["trim_rec"]],
                [cwlout(["align_bam"], "File", [".bai"])],
-               "bcbio-rnaseq", ["star", "hisat2", "tophat", "samtools",
+               "bcbio-rnaseq", ["star", "hisat2", "tophat;env=python2", "samtools",
                                 "sambamba", "seqtk"],
                {"files": 1.5})]
     if checkpoints.get("vc"):
@@ -633,7 +637,7 @@ def rnaseq(samples):
                    cwlout(["quant", "hdf5"], "File"),
                    cwlout(["quant", "fusion"], "File")],
                   "bcbio-rnaseq", programs=["sailfish", "salmon", "kallisto>=0.43.1", "subread", "gffread",
-                                            "r=3.4.1", "r-base=3.4.1=h4fe35fd_8", "xorg-libxt", "r-wasabi"],
+                                            "r=3.5.1", "r-base", "xorg-libxt", "r-wasabi"],
                   disk={"files": 0.5})]
     qc = [s("qc_to_rec", "multi-combined",
             [["align_bam"], ["analysis"], ["reference", "fasta", "base"], dd.get_keys("gtf_file"),
