@@ -32,10 +32,10 @@ from bcbio.pipeline import datadict as dd
 
 REMOTES = {
     "requirements": "https://raw.githubusercontent.com/bcbio/bcbio-nextgen/master/requirements-conda.txt",
-    "gitrepo": "https://github.com/bcbio/bcbio-nextgen.git",
-    "cloudbiolinux": "https://github.com/chapmanb/cloudbiolinux/archive/master.tar.gz",
+    "gitrepo": "https://github.com/bcbio/bcbio-nextgen/archive/%s.tar.gz",
+    "cloudbiolinux": "https://github.com/chapmanb/cloudbiolinux/archive/%s.tar.gz",
     "genome_resources": "https://raw.githubusercontent.com/bcbio/bcbio-nextgen/master/config/genomes/%s-resources.yaml",
-    "snpeff_dl_url": ("http://downloads.sourceforge.net/project/snpeff/databases/v{snpeff_ver}/"
+    "snpeff_dl_url": ("https://snpeff.blob.core.windows.net/databases/v{snpeff_ver}/"
                       "snpEff_v{snpeff_ver}_{genome}.zip")}
 SUPPORTED_GENOMES = ["GRCh37", "hg19", "hg38", "hg38-noalt", "mm10", "mm9",
                      "rn6", "rn5", "canFam3", "dm3", "galGal4", "phix",
@@ -62,9 +62,11 @@ def upgrade_bcbio(args):
             _check_for_conda_problems()
             print("Upgrading bcbio-nextgen to latest development version")
             pip_bin = os.path.join(os.path.dirname(os.path.realpath(sys.executable)), "pip")
-            git_tag = "@%s" % args.revision if args.revision != "master" else ""
-            _pip_safe_ssl([[pip_bin, "install", "--upgrade", "--no-deps",
-                            "git+%s%s#egg=bcbio-nextgen" % (REMOTES["gitrepo"], git_tag)]], anaconda_dir)
+            # default is master
+            # egg installation with --update is not always working
+            git_url = REMOTES["gitrepo"] % args.revision
+            _pip_safe_ssl([[pip_bin, "install", "--force-reinstall", "--no-deps",
+                           git_url]], anaconda_dir)
             print("Upgrade of bcbio-nextgen development code complete.")
         else:
             _update_conda_packages()
@@ -350,7 +352,7 @@ def upgrade_bcbio_data(args, remotes):
         data_dir = _get_data_dir()
     tooldir = args.tooldir or get_defaults().get("tooldir")
     galaxy_home = os.path.join(data_dir, "galaxy")
-    cbl = get_cloudbiolinux(remotes)
+    cbl = get_cloudbiolinux(args, remotes)
     tool_data_table_conf_file = os.path.join(cbl["dir"], "installed_files", "tool_data_table_conf.xml")
     genome_opts = _get_biodata(cbl["biodata"], args)
     sys.path.insert(0, cbl["dir"])
@@ -413,8 +415,7 @@ def _upgrade_vep_data(galaxy_dir, tooldir):
         effects.prep_vep_cache(dbkey, ref_file, tooldir)
 
 def _upgrade_snpeff_data(galaxy_dir, args, remotes):
-    """Install or upgrade snpEff databases, localized to reference directory.
-    """
+    """Install or upgrade snpEff databases, localized to reference directory."""
     snpeff_version = effects.snpeff_version(args)
     if not snpeff_version:
         return
@@ -498,7 +499,7 @@ def upgrade_thirdparty_tools(args, remotes):
     conda_bin = _get_mamba_bin()
     if not conda_bin:
         conda_bin = _get_conda_bin()
-    cbl = get_cloudbiolinux(remotes)
+    cbl = get_cloudbiolinux(args, remotes)
     if args.toolconf and os.path.exists(args.toolconf):
         package_yaml = args.toolconf
     else:
@@ -794,17 +795,20 @@ def add_subparser(subparsers):
                         dest="cwl", action="store_true", default=False)
     parser.add_argument("--isolate", help="Created an isolated installation without PATH updates",
                         dest="isolate", action="store_true", default=False)
+    parser.add_argument("--cloudbiolinux", help="Specify a cloudbiolinux git commit hash or tag to install",
+                        default="master")
     parser.add_argument("--distribution", help="Operating system distribution",
                         default="",
                         choices=["ubuntu", "debian", "centos", "scientificlinux", "macosx"])
     return parser
 
-def get_cloudbiolinux(remotes):
+def get_cloudbiolinux(args, remotes):
     base_dir = os.path.join(os.getcwd(), "cloudbiolinux")
+    cloudbiolinux_remote = remotes["cloudbiolinux"] % args.cloudbiolinux
     if not os.path.exists(base_dir):
         subprocess.check_call("wget --progress=dot:mega --no-check-certificate -O- %s | tar xz && "
-                              "(mv cloudbiolinux-master cloudbiolinux || mv master cloudbiolinux)"
-                              % remotes["cloudbiolinux"], shell=True)
+                              "(mv cloudbiolinux-%s cloudbiolinux || mv %s cloudbiolinux)"
+                              % (cloudbiolinux_remote, args.cloudbiolinux, args.cloudbiolinux), shell=True)
     return {"biodata": os.path.join(base_dir, "config", "biodata.yaml"),
             "dir": base_dir}
 
