@@ -39,6 +39,9 @@ def create_inputs(data):
         # skip indexing on samples without input files or not doing alignment
         if ("files" not in data or not data["files"] or data["files"][0] is None or not aligner):
             return [[data]]
+        # if this is a DRAGEN BAM, we need to do further alignments with this BAM, so don't convert it
+        if dd.get_umi_type(data) == "dragen":
+            return [[data]]
     data["files_orig"] = data["files"]
     data["files"] = prep_fastq_inputs(data["files"], data)
     # preparation converts illumina into sanger format
@@ -286,7 +289,7 @@ def total_reads_from_grabix(in_file):
         with open(gbi_file) as in_handle:
             next(in_handle)  # throw away
             num_lines = int(next(in_handle).strip())
-        assert num_lines % 4 == 0, "Expected lines to be multiple of 4"
+        assert num_lines % 4 == 0, f"Expected lines to be multiple of 4 for file: {in_file} with {num_lines} lines"
         return num_lines // 4
     else:
         return 0
