@@ -61,7 +61,8 @@ def _set_rg_options(options, names):
 def _set_stranded_flag(options, config):
     strand_flag = {"unstranded": "fr-unstranded",
                    "firststrand": "fr-firststrand",
-                   "secondstrand": "fr-secondstrand"}
+                   "secondstrand": "fr-secondstrand",
+                   "auto": "fr-unstranded"}
     stranded = get_in(config, ("algorithm", "strandedness"), "unstranded").lower()
     assert stranded in strand_flag, ("%s is not a valid strandedness value. "
                                      "Valid values are 'firststrand', "
