@@ -30,6 +30,11 @@ def singlecell_rnaseq(samples, run_parallel):
     for lane in demultiplexed:
         for index in lane:
             samples.append([index])
+    if not samples:
+        logger.error(f"No samples were found matching the supplied sample barcodes. See "
+            f"https://github.com/bcbio/bcbio-nextgen/issues/3428#issuecomment-772609904 "
+            f"for how to debug this issue.")
+        sys.exit(1)
     samples = run_parallel("run_filter_barcodes", samples)
     samples = run_parallel("run_barcode_histogram", samples)
     if quantifier == "rapmap":
@@ -482,17 +487,6 @@ def combine_files(samples):
         dexseq_combined = None
     samples = spikein.combine_spikein(samples)
     tximport = load_tximport(data)
-    # don't fail runs while we get dependencies straightened out
-    try:
-        # we need metadata.csv to generate SE
-        work_dir = dd.get_work_dir(data)
-        metadata_file = os.path.join(work_dir, "metadata.csv")
-        if not file_exists(metadata_file):
-            qcsummary._merge_metadata(samples)
-        summarized_experiment = load_summarizedexperiment(data)
-        qc_report = generate_se_qc_report(data)
-    except Exception:
-        summarized_experiment = None
     updated_samples = []
     for data in dd.sample_data_iterator(samples):
         if combined:
@@ -513,7 +507,6 @@ def combine_files(samples):
         if gtf_file:
             data = dd.set_tx2gene(data, tx2gene_file)
         data = dd.set_tximport(data, tximport)
-        data = dd.set_summarized_experiment(data, summarized_experiment)
         updated_samples.append([data])
     return updated_samples
 
@@ -539,7 +532,7 @@ def determine_indexes_to_make(samples):
     return tomake
 
 def load_tximport(data):
-    rcmd = Rscript_cmd("r36")
+    rcmd = Rscript_cmd("base")
     salmon_dir = os.path.join(dd.get_work_dir(data), "salmon")
     tx2gene_file = os.path.join(dd.get_work_dir(data), "inputs", "transcriptome", "tx2gene.csv")
     out_dir = os.path.join(salmon_dir, "combined")
@@ -564,30 +557,43 @@ def load_tximport(data):
     return {"gene_tpm": tpm_file,
             "gene_counts": counts_file}
 
-def load_summarizedexperiment(data):
+def load_summarizedexperiment(samples):
     """ create summarizedexperiment rds object
     fails with n_samples = 1 """
-    # using r36 (4.0) - will eventually drop R3.5
-    rcmd = Rscript_cmd("r36")
+    rcmd = Rscript_cmd("base")
     se_script = os.path.join(os.path.dirname(__file__), os.pardir, "scripts",
                              "R", "bcbio2se.R")
+    data = samples[0][0]
     work_dir = dd.get_work_dir(data)
     out_dir = os.path.join(work_dir, "salmon")
-    out_file = os.path.join(out_dir, "bcbio-se.rds")
-    if file_exists(out_file):
-        return out_file
-    with file_transaction(out_file) as tx_out_file:
-        cmd = f"{rcmd} --vanilla {se_script} {work_dir} {tx_out_file}"
-        message = f"Loading SummarizedExperiment."
-        do.run(cmd, message)
-    return out_file
+    summarized_experiment = os.path.join(out_dir, "bcbio-se.rds")
+    if not file_exists(summarized_experiment):
+        with file_transaction(summarized_experiment) as tx_out_file:
+            cmd = f"{rcmd} --vanilla {se_script} {work_dir} {tx_out_file}"
+            message = f"Loading SummarizedExperiment."
+            try:
+                do.run(cmd, message)
+            except Exception:
+                logger.error("SE creation failed")
+    if file_exists(summarized_experiment):
+        try:
+            se_qc_report = generate_se_qc_report(work_dir)
+        except Exception:
+            se_qc_report = None
+            logger.error("SE QC failed")
+        updated_samples = []
+        for data in dd.sample_data_iterator(samples):
+            data = dd.set_summarized_experiment(data, summarized_experiment)
+            updated_samples.append([data])
+        return updated_samples
+    else:
+        return samples
 
-def generate_se_qc_report(data):
+def generate_se_qc_report(work_dir):
     """ generate QC report based on SE RDS object"""
-    rcmd = Rscript_cmd("r36")
+    rcmd = Rscript_cmd("base")
     qc_script = os.path.join(os.path.dirname(__file__), os.pardir, "scripts",
                              "R", "se2qc.Rmd")
-    work_dir = dd.get_work_dir(data)
     out_file = os.path.join(work_dir, "qc", "bcbio-se.html")
     rds_file = os.path.join(work_dir, "salmon", "bcbio-se.rds")
     if file_exists(out_file):
