@@ -726,12 +726,15 @@ def _check_hetcaller(item):
     """Ensure upstream SV callers requires to heterogeneity analysis are available.
     purecn has its own segmentation - no need in cnvkit or gatk-cnv
     """
-    svs = _get_as_list(item, "svcaller")
     hets = _get_as_list(item, "hetcaller")
-    if hets or any([x in svs for x in ["titancna"]]):
-        if not any([x in svs for x in ["cnvkit", "gatk-cnv"]]):
-            raise ValueError("Heterogeneity caller used but need CNV calls. Add `gatk-cnv` "
-                             "or `cnvkit` to `svcaller` in sample: %s" % item["description"])
+    svs = _get_as_list(item, "svcaller")
+    needing_cnv = hets.copy()
+    for s in svs:
+        if s in ["titancna"]:
+            needing_cnv.append(s)
+    if needing_cnv and not any([x in svs for x in ["cnvkit", "gatk-cnv"]]):
+            raise ValueError("Heterogeneity caller(s) %s used but need CNV calls. Add `gatk-cnv` "
+                             "or `cnvkit` to `svcaller` in sample: %s" % (", ".join(needing_cnv), item["description"]))
 
 def _check_jointcaller(data):
     """Ensure specified jointcaller is valid.
@@ -778,9 +781,15 @@ def _check_trim(data):
                              (dd.get_sample_name(data)))
 
 
+def _check_hla_align(data):
+    """ Check for align: bwa if hlacaller: optitype """
+    algorithm = tz.get_in(["algorithm"], data)
+    if algorithm and "aligner" in algorithm and "hlacaller" in algorithm:
+        if algorithm["aligner"] != "bwa" and algorithm["hlacaller"].lower() == "optitype":
+            raise ValueError(f"In sample {dd.get_sample_name(data)}, hlacaller: optitype requires aligner: bwa")
+
 def _check_sample_config(items, in_file, config):
-    """Identify common problems in input sample configuration files.
-    """
+    """Identify common problems in input sample configuration files."""
     logger.info("Checking sample YAML configuration: %s" % in_file)
     _check_quality_format(items)
     _check_for_duplicates(items, "lane")
@@ -804,6 +813,7 @@ def _check_sample_config(items, in_file, config):
     [_check_hlacaller(x) for x in items]
     [_check_realign(x) for x in items]
     [_check_trim(x) for x in items]
+    [_check_hla_align(x) for x in items]
 
 # ## Read bcbio_sample.yaml files
 
