@@ -1,5 +1,5 @@
 """High level entry point for processing a sample.
-c
+
 Samples may include multiple lanes, or barcoded subsections of lanes,
 processed together.
 """
@@ -22,7 +22,7 @@ from bcbio.ngsalign import postalign
 from bcbio.pipeline.fastq import get_fastq_files
 from bcbio.pipeline.alignment import align_to_sort_bam
 from bcbio.pipeline import cleanbam
-from bcbio.variation import coverage, recalibrate
+from bcbio.variation import coverage, recalibrate, gatk
 from bcbio.variation import multi as vmulti
 import bcbio.pipeline.datadict as dd
 from bcbio.pipeline.fastq import merge as fq_merge
@@ -33,6 +33,7 @@ from bcbio.structural.seq2c import prep_seq2c_bed
 from bcbio.variation.bedutils import clean_file, merge_overlaps
 from bcbio.structural import get_svcallers, regions
 from bcbio.qc import samtools
+from bcbio.dragen import dragen
 
 def prepare_sample(data):
     """Prepare a sample to be run, potentially converting from BAM to
@@ -104,7 +105,11 @@ def _add_hla_files(data):
     """
     if "hla" not in data:
         data["hla"] = {}
-    align_file = dd.get_align_bam(data)
+    # if HLA bam was created separately, FASTQ files will be based off of it
+    if dd.get_hla_bam(data):
+        align_file = dd.get_hla_bam(data)
+    else:
+        align_file = dd.get_align_bam(data)
     hla_dir = os.path.join(os.path.dirname(align_file), "hla")
     if not os.path.exists(hla_dir):
         hla_files = None
@@ -124,11 +129,20 @@ def process_alignment(data, alt_input=None):
     config = data["config"]
     aligner = config["algorithm"].get("aligner", None)
     if fastq1 and objectstore.file_exists_or_remote(fastq1) and aligner:
-        logger.info("Aligning lane %s with %s aligner" % (data["rgnames"]["lane"], aligner))
-        data = align_to_sort_bam(fastq1, fastq2, aligner, data)
+        if dd.get_umi_type(data) == "dragen":
+            assert bam.is_bam(fastq1), f"umi_type: dragen needs a BAM file as input."
+            data = dragen.fix_umi_dragen_bam(data, bam=fastq1)
+#            fastq1 = bam.sort(fastq1, dd.get_config(data))
+#            bam.index(fastq1, dd.get_config(data))
+#            data["work_bam"] = fastq1
+        else:
+#            logger.info("Aligning lane %s with %s aligner" % (data["rgnames"]["lane"], aligner))
+            data = align_to_sort_bam(fastq1, fastq2, aligner, data)
+        if dd.get_correct_umis(data):
+            data["work_bam"] = postalign.correct_umis(data)
         if dd.get_umi_consensus(data):
             data["umi_bam"] = dd.get_work_bam(data)
-            if fastq2:
+            if fastq2 or dd.get_umi_type(data) == "dragen":
                 f1, f2, avg_cov = postalign.umi_consensus(data)
                 data["config"]["algorithm"]["rawumi_avg_cov"] = avg_cov
                 del data["config"]["algorithm"]["umi_type"]
@@ -145,7 +159,8 @@ def process_alignment(data, alt_input=None):
             if sort_method and sort_method != "coordinate":
                 raise ValueError("Cannot specify `bam_clean: picard` with `bam_sort` other than coordinate: %s"
                                  % sort_method)
-            out_bam = cleanbam.picard_prep(fastq1, data["rgnames"], dd.get_ref_file(data), data["dirs"],
+            ref_file = dd.get_ref_file(data)
+            out_bam = cleanbam.picard_prep(fastq1, data["rgnames"], ref_file, data["dirs"],
                                            data)
         elif bamclean == "fixrg":
             out_bam = cleanbam.fixrg(fastq1, data["rgnames"], dd.get_ref_file(data), data["dirs"], data)
@@ -225,7 +240,7 @@ def clean_inputs(data):
         data["config"]["algorithm"]["coverage"] = clean_cov_bed
         data["config"]["algorithm"]["coverage_merged"] = merged_cov_bed
 
-    if 'seq2c' in get_svcallers(data):
+    if "seq2c" in get_svcallers(data):
         seq2c_ready_bed = prep_seq2c_bed(data)
         if not seq2c_ready_bed:
             logger.warning("Can't run Seq2C without a svregions or variant_regions BED file")
@@ -233,6 +248,14 @@ def clean_inputs(data):
             data["config"]["algorithm"]["seq2c_bed_ready"] = seq2c_ready_bed
     elif regions.get_sv_bed(data):
         dd.set_sv_regions(data, clean_file(regions.get_sv_bed(data), data, prefix="svregions-"))
+
+    if "purecn" in get_svcallers(data):
+        from bcbio.structural import purecn
+        purecn_ready_bed = purecn.process_intervals(data)
+        if not purecn_ready_bed:
+            logger.warning("Can't run PureCN without a svregions or variant_regions BED file")
+        else:
+            data["config"]["algorithm"]["purecn_bed_ready"] = purecn_ready_bed
     return data
 
 def postprocess_alignment(data):
@@ -243,6 +266,11 @@ def postprocess_alignment(data):
     data = cwlutils.unpack_tarballs(data, data)
     bam_file = data.get("align_bam") or data.get("work_bam")
     ref_file = dd.get_ref_file(data)
+    artifacts = gatk.collect_artifact_metrics(data)
+    if artifacts:
+        data = dd.update_summary_qc(data, "picard", artifacts.pop(), artifacts)
+        oxog = gatk.collect_oxog_metrics(data)
+        data = dd.update_summary_qc(data, "picard", oxog.pop(), oxog)
     if vmulti.bam_needs_processing(data) and bam_file and bam_file.endswith(".bam"):
         out_dir = utils.safe_makedir(os.path.join(dd.get_work_dir(data), "align",
                                                   dd.get_sample_name(data)))
