@@ -12,7 +12,7 @@ from bcbio.cwl import cwlutils
 from bcbio.pipeline import datadict as dd
 from bcbio.structural import (battenberg, cn_mops, cnvkit, delly, gatkcnv, gridss,
                               lumpy, manta, metasv, prioritize, purecn, purple, plot,
-                              seq2c, titancna, validate, wham)
+                              scramble, seq2c, titancna, validate, wham)
 from bcbio.variation import validate as vcvalidate
 from bcbio.variation import vcfutils
 
@@ -27,13 +27,13 @@ _CALLERS = {
                "delly": delly.run, "lumpy": lumpy.run, "wham": wham.run,
                "battenberg": battenberg.run, "seq2c": seq2c.run, "gridss": gridss.run,
                "titancna": titancna.run, "purecn": purecn.run, "purple": purple.run,
-               "gatk-cnv": gatkcnv.run},
+               "gatk-cnv": gatkcnv.run, "scramble": scramble.run},
   "ensemble": {"metasv": metasv.run,
                "prioritize": prioritize.run}}
 _NEEDS_BACKGROUND = set(["cn.mops"])
 _GLOBAL_BATCHING = set(["seq2c"])
 # CNV callers that have background references
-_CNV_REFERENCE = set(["seq2c", "cnvkit", "gatk-cnv"])
+_CNV_REFERENCE = set(["seq2c", "cnvkit", "gatk-cnv", "purecn"])
 
 def _get_callers(items, stage, special_cases=False):
     """Retrieve available callers for the provided stage.
@@ -54,6 +54,7 @@ def _get_callers(items, stage, special_cases=False):
     return callers
 
 def get_svcallers(data):
+    """why this exists? dd.get_svcaller(data)"""
     svs = data["config"]["algorithm"].get("svcaller")
     if svs is None:
         svs = []
@@ -63,6 +64,7 @@ def get_svcallers(data):
 
 def _handle_multiple_svcallers(data, stage):
     """Retrieve configured structural variation caller, handling multiple.
+       data is one sample
     """
     svs = get_svcallers(data)
     # special cases -- prioritization
@@ -130,6 +132,36 @@ def validate_sv(data):
     """
     return [[validate.evaluate(data)]]
 
+def create_cnv_pon(samples):
+    """create normal db using SNV PON and coverage information"""
+    coverage_files = []
+    sample0 = utils.to_single_data(samples[0])
+    genome = dd.get_genome_build(sample0)
+    purecn_pon_build = tz.get_in(["config", "algorithm", "purecn_pon_build"], sample0)
+    if purecn_pon_build:
+
+        for sample in (utils.to_single_data(x) for x in samples):
+            sample_coverage = tz.get_in(["depth", "bins", "purecn"], sample)
+
+            if os.path.exists(sample_coverage):
+                coverage_files.append(sample_coverage)
+
+        work_dir = tz.get_in(["dirs", "work"], sample0)
+        out_dir = utils.safe_makedir(os.path.join(work_dir, "gemini"))
+        purecn_coverage_files_txt = os.path.join(out_dir, "purecn_coverage_files.txt")
+
+        with open(purecn_coverage_files_txt, "w") as out_handle:
+            for fname in coverage_files:
+                out_handle.write(fname + "\n")
+            
+        snv_pon = tz.get_in(["config", "algorithm", "purecn_snv_pon"], sample0)
+        normal_db = os.path.join(out_dir, "normalDB_{}.rds".format(genome))
+        # delete normal db in work/gemini if you'd like to rebuild it!
+        if os.path.exists(snv_pon) and len(coverage_files) >= 3 and not os.path.exists(normal_db):
+            purecn.create_normal_db(purecn_coverage_files_txt, snv_pon,
+                                    out_dir, genome)
+    return samples
+
 def batch_for_sv(samples):
     """Prepare a set of samples for parallel structural variant calling.
 
@@ -142,13 +174,21 @@ def batch_for_sv(samples):
     return out
 
 def _batch_split_by_sv(samples, stage):
+    """Return
+    - to_process = svcaller-batch => [svcaller-sample1, svcaller-sample2...] odict
+    - extras = samples without sv calling (should there be any?)
+    - background - all samples
+    """
     to_process = collections.OrderedDict()
     extras = []
     background = []
     for data in (utils.to_single_data(x) for x in samples):
+        # data = sample
         ready_data = _handle_multiple_svcallers(data, stage)
         if len(ready_data) > 0:
+            # why appending every sample to background?
             background.append(data)
+            # x is sample - sv caller pair
             for x in ready_data:
                 svcaller = tz.get_in(["config", "algorithm", "svcaller"], x)
                 batch = dd.get_batch(x) or dd.get_sample_name(x)
@@ -161,12 +201,16 @@ def _batch_split_by_sv(samples, stage):
                         batch += "_germline"
                 elif svcaller in _GLOBAL_BATCHING:  # All samples batched together for analyses
                     batch = "all"
-                batches = batch if isinstance(batch, (list, tuple)) else [batch]
-                for b in batches:
-                    try:
-                        to_process[(svcaller, b)].append(x)
-                    except KeyError:
-                        to_process[(svcaller, b)] = [x]
+                # just creating PON - no calling
+                if stage in ["standard"] and batch in ["pon_build"]:
+                    extras.append(x)
+                else:
+                    batches = batch if isinstance(batch, (list, tuple)) else [batch]
+                    for b in batches:
+                        try:
+                            to_process[(svcaller, b)].append(x)
+                        except KeyError:
+                            to_process[(svcaller, b)] = [x]
         else:
             extras.append([data])
     return to_process, extras, background
@@ -188,12 +232,17 @@ def run(samples, run_parallel, stage):
 
 def detect_sv(items, all_items=None, stage="standard"):
     """Top level parallel target for examining structural variation.
+    items = sample-sv_caller list, from one batch
     """
     items = [utils.to_single_data(x) for x in items]
     items = cwlutils.unpack_tarballs(items, items[0])
     svcaller = items[0]["config"]["algorithm"].get("svcaller")
     caller_fn = _get_callers(items, stage, special_cases=True).get(svcaller)
     out = []
+    batch = dd.get_batch(items[0])
+    # no SV calling when just creating a PON for PureCN
+    if batch == "pon_build" and "purecn" in dd.get_svcaller(items[0]):
+        return out
     if svcaller and caller_fn:
         if (all_items and svcaller in _NEEDS_BACKGROUND and
                 not vcfutils.is_paired_analysis([x.get("align_bam") for x in items], items)):
