@@ -5,7 +5,6 @@ https://github.com/Illumina/manta
 import collections
 import glob
 import os
-import sys
 
 from bcbio import utils
 from bcbio.bam import ref
@@ -34,8 +33,9 @@ def run(items):
     out = []
     upload_counts = collections.defaultdict(int)
     for data in items:
-        if paired and paired.normal_bam and "break-point-inspector" in dd.get_tools_on(data):
-            variant_file = _run_break_point_inspector(data, variant_file, paired)
+        if "break-point-inspector" in dd.get_tools_on(data):
+            if paired and paired.normal_bam and paired.tumor_name == dd.get_sample_name(data):
+                variant_file = _run_break_point_inspector(data, variant_file, paired, work_dir)
         if "sv" not in data:
             data["sv"] = []
         final_vcf = shared.finalize_sv(variant_file, data, items)
@@ -50,21 +50,21 @@ def run(items):
         out.append(data)
     return out
 
-def _run_break_point_inspector(data, variant_file, paired):
+def _run_break_point_inspector(data, variant_file, paired, work_dir):
     output_vcf = "%s-%s.vcf.gz" % (utils.splitext_plus(variant_file)[0], "bpi")
+    stats_file = "%s-%s_stats.txt" % (utils.splitext_plus(variant_file)[0], "bpi")
     if not utils.file_exists(output_vcf):
-        with file_transaction(data, output_vcf) as tx_output_vcf:
+        with file_transaction(data, output_vcf) as tx_output_vcf, file_transaction(data, stats_file) as tx_stats_file:
             cores = dd.get_num_cores(data)
             resources = config_utils.get_resources("break-point-inspector", data["config"])
-            memory = config_utils.adjust_opts(resources.get("jvm_opts", ["-Xms1000m", "-Xmx2000m"]),
-                                              {"algorithm": {"memory_adjust": {"magnitude": cores,
-                                                                               "direction": "increase"}}})
-            cmd = ["break-point-inspector"]
-            cmd += memory
-            cmd += ["-vcf", variant_file]
+            jvm_mem_opts = config_utils.adjust_opts(resources.get("jvm_opts", ["-Xms1000m", "-Xmx2000m"]),
+                                                    {"algorithm": {"memory_adjust": {"magnitude": cores,
+                                                                                     "direction": "increase"}}})
+            jvm_tmp_arg = "-Djava.io.tmpdir=" + utils.safe_makedir(os.path.join(work_dir, "bpi_tmp"))
+            cmd = ["break-point-inspector"] + jvm_mem_opts + [jvm_tmp_arg, "-vcf", variant_file]
             if paired:
                 cmd += ["-ref", paired.normal_bam, "-tumor", paired.tumor_bam]
-            cmd += ["-output_vcf", tx_output_vcf]
+            cmd += ["-output_vcf", tx_output_vcf, ">", tx_stats_file]
             do.run(cmd, "Running Break Point Inspector for Manta SV calls")
     return output_vcf
 
@@ -93,7 +93,7 @@ def _run_workflow(items, paired, workflow_file, work_dir):
     """
     utils.remove_safe(os.path.join(work_dir, "workspace"))
     data = paired.tumor_data if paired else items[0]
-    cmd = [sys.executable, workflow_file, "-m", "local", "-j", dd.get_num_cores(data)]
+    cmd = [utils.get_program_python("configManta.py"), workflow_file, "-m", "local", "-j", dd.get_num_cores(data)]
     do.run(cmd, "Run manta SV analysis")
     utils.remove_safe(os.path.join(work_dir, "workspace"))
 
@@ -104,7 +104,7 @@ def _prep_config(items, paired, work_dir):
     out_file = os.path.join(work_dir, "runWorkflow.py")
     if not utils.file_exists(out_file) or _out_of_date(out_file):
         config_script = os.path.realpath(utils.which("configManta.py"))
-        cmd = [sys.executable, config_script]
+        cmd = [utils.get_program_python("configManta.py"), config_script]
         if paired:
             if paired.normal_bam:
                 cmd += ["--normalBam=%s" % paired.normal_bam, "--tumorBam=%s" % paired.tumor_bam]
