@@ -14,6 +14,7 @@ from bcbio import utils
 from bcbio.heterogeneity import chromhacks
 from bcbio.log import logger
 from bcbio.pipeline import datadict as dd
+from bcbio.pipeline import config_utils
 from bcbio.distributed.transaction import file_transaction
 from bcbio.heterogeneity import loh
 from bcbio.provenance import do
@@ -32,10 +33,11 @@ def run(items):
     # the right way of running purecn is with normaldb
     if normaldb:
         purecn_out = _run_purecn_normaldb(paired, work_dir)
+        # don't run signature analysis if there is no purecn solution
+        if "rds" in purecn_out:
+            purecn_out = _run_purecn_dx(purecn_out, paired)
     else:
         purecn_out = _run_purecn(paired, work_dir)
-    # XXX Currently finding edge case failures with Dx calling, needs additional testing
-    # purecn_out = _run_purecn_dx(purecn_out, paired)
     out = []
     if paired.normal_data:
         out.append(paired.normal_data)
@@ -54,14 +56,13 @@ def run(items):
 
 def _run_purecn_normaldb(paired, out):
     """Run PureCN with normaldb and native segmentation
-       paired is one t/n pair or only t
-    """
+       paired is one t/n pair or only """
     sample = utils.to_single_data(paired.tumor_data)
     bed_file = tz.get_in(["config", "algorithm", "purecn_bed_ready"], sample)
     sample_name = dd.get_sample_name(sample)
     work_dir = _sv_workdir(sample)
-    rscript = utils.Rscript_cmd("r36")
-    purecn_r = utils.R_package_script("r36", "PureCN", "extdata/PureCN.R")
+    rscript = utils.Rscript_cmd()
+    purecn_r = utils.R_package_script("PureCN", "extdata/PureCN.R", env="base")
     intervals = tz.get_in(["config", "algorithm", "purecn_bed_ready"], sample)
     bam_file = dd.get_align_bam(sample)
     # termline and somatic - just annotated and filters assigned
@@ -81,15 +82,18 @@ def _run_purecn_normaldb(paired, out):
             "--sampleid", sample_name,
             "--vcf", variants_vcf,
             "--normaldb", normaldb,
-            "--mappingbiasfile", mappingbiasfile,
+            "--mapping-bias-file", mappingbiasfile,
             "--intervals", intervals,
-            "--snpblacklist", simple_repeat_bed,
+            "--snp-blacklist", simple_repeat_bed,
             "--genome", genome,
             "--force",
-            "--postoptimize",
+            "--post-optimize",
             "--seed", "123",
             "--bootstrapn", "500",
             "--cores", dd.get_num_cores(sample)]
+    resources = config_utils.get_resources("purecn", sample)
+    if "options" in resources:
+        cmd += [str(x) for x in resources.get("options", [])]
     # it is not recommended to use matched normal sample in PureCN analysis,
     # because then it skips PON coverage normalization and denoising steps!
     # but still, if it is supplied, we useit
@@ -100,8 +104,8 @@ def _run_purecn_normaldb(paired, out):
             cmd.extend(["--normal", normal_coverage])
     if not os.path.exists(result_file):
         try:
-            cmd_line = "export R_LIBS_USER=%s && %s && %s" % (utils.R_sitelib(env = "r36"),
-                                                              utils.get_R_exports(env = "r36"),
+            cmd_line = "export R_LIBS_USER=%s && %s && %s" % (utils.R_sitelib(env = "base"),
+                                                              utils.get_R_exports(env = "base"),
                                                               " ".join([str(x) for x in cmd]))
             do.run(cmd_line, "PureCN copy number calling")
             logger.debug("Saved PureCN output to " + work_dir)
@@ -111,31 +115,46 @@ def _run_purecn_normaldb(paired, out):
     return out
 
 def _run_purecn_dx(out, paired):
-    """Extract signatures and mutational burdens from PureCN rds file.
-    """
-    out_base, out, all_files = _get_purecn_dx_files(paired, out)
-    if not utils.file_uptodate(out["mutation_burden"], out["rds"]):
+    """Extract signatures and mutational burdens from PureCN rds file."""
+    # no solution - no signatures
+    if not "rds" in out:
+        return out
+    rscript = utils.Rscript_cmd()
+    purecndx_r = utils.R_package_script("PureCN", "extdata/Dx.R", env="base")
+    simple_repeat_bed = dd.get_variation_resources(paired.tumor_data)["simple_repeat"]
+    callable_bed = dd.get_sample_callable(paired.tumor_data)
+    out_base = utils.splitext_plus(out["rds"])[0]
+    mutation_burden_csv = out_base + "_mutation_burden.csv"
+    if not utils.file_uptodate(mutation_burden_csv, out["rds"]):
+        # no signatures - so we generate them
         with file_transaction(paired.tumor_data, out_base) as tx_out_base:
-            cmd = ["PureCN_Dx.R", "--rds", out["rds"], "--callable", dd.get_sample_callable(paired.tumor_data),
-                   "--signatures", "--out", tx_out_base]
+            cmd = [rscript, purecndx_r, 
+                   "--rds", out["rds"], 
+                   "--callable", callable_bed,
+                   "--signatures",
+                   "--exclude", simple_repeat_bed,
+                   "--out", tx_out_base]
             do.run(cmd, "PureCN Dx mutational burden and signatures")
+            out_base, out, all_files = _get_purecn_dx_files(paired, out, require_exist = True)
+            # if a file was not generated it would not go to the upload
             for f in all_files:
                 if os.path.exists(os.path.join(os.path.dirname(tx_out_base), f)):
                     shutil.move(os.path.join(os.path.dirname(tx_out_base), f),
                                 os.path.join(os.path.dirname(out_base), f))
     return out
 
-def _get_purecn_dx_files(paired, out):
-    """Retrieve files generated by PureCN_Dx
-    """
-    out_base = "%s-dx" % utils.splitext_plus(out["rds"])[0]
+def _get_purecn_dx_files(paired, out, require_exist = False):
+    """Retrieve files generated by PureCN_Dx"""
+    out_base = utils.splitext_plus(out["rds"])[0]
     all_files = []
     for key, ext in [[("mutation_burden",), "_mutation_burden.csv"],
                      [("plot", "signatures"), "_signatures.pdf"],
-                     [("signatures",), "_signatures.csv"]]:
-        cur_file = "%s%s" % (out_base, ext)
-        out = tz.update_in(out, key, lambda x: cur_file)
-        all_files.append(os.path.basename(cur_file))
+                     [("signatures",), "_signatures.csv"],
+                     [("chrom_instability",), "_cin.csv"]]:
+        cur_file = f"{out_base}{ext}"
+        if not require_exist or os.path.exists(cur_file):
+            out = tz.update_in(out, key, lambda x: cur_file)
+            all_files.append(os.path.basename(cur_file))
     return out_base, out, all_files
 
 def _run_purecn(paired, work_dir):
@@ -154,7 +173,10 @@ def _run_purecn(paired, work_dir):
             # Use UCSC style naming for human builds to support BSgenome
             genome = ("hg19" if dd.get_genome_build(paired.tumor_data) in ["GRCh37", "hg19"]
                       else dd.get_genome_build(paired.tumor_data))
-            cmd = ["PureCN.R", "--seed", "42", "--out", tx_out_base, "--rds", "%s.rds" % tx_out_base,
+            rscript = utils.Rscript_cmd()
+            purecn_r = utils.R_package_script("PureCN", "extdata/PureCN.R", env="base")
+            cmd = [rscript, purecn_r, "--seed", "42", "--out", tx_out_base, 
+                   "--rds", "%s.rds" % tx_out_base,
                    "--sampleid", dd.get_sample_name(paired.tumor_data),
                    "--genome", genome,
                    "--vcf", vcf_file, "--tumor", cnr_file,
@@ -162,8 +184,8 @@ def _run_purecn(paired, work_dir):
             if dd.get_num_cores(paired.tumor_data) > 1:
                 cmd += ["--cores", str(dd.get_num_cores(paired.tumor_data))]
             try:
-                cmd = "export R_LIBS_USER=%s && %s && %s" % (utils.R_sitelib(env="r36"),
-                                                             utils.get_R_exports(env="r36"),
+                cmd = "export R_LIBS_USER=%s && %s && %s" % (utils.R_sitelib(env="base"),
+                                                             utils.get_R_exports(env="base"),
                                                              " ".join([str(x) for x in cmd]))
                 do.run(cmd, "PureCN copy number calling")
             except subprocess.CalledProcessError as msg:
@@ -250,23 +272,27 @@ def _remove_overlaps(in_file, out_dir, data):
     return out_file
 
 def _get_purecn_files(paired, work_dir, require_exist=False):
-    """Retrieve organized structure of PureCN output files.
-    """
-    out_base = os.path.join(work_dir, "%s-purecn" % (dd.get_sample_name(paired.tumor_data)))
+    """Retrieve organized structure of PureCN output files."""
+    sample_name = dd.get_sample_name(paired.tumor_data)
+    out_base = os.path.join(work_dir, sample_name)
     out = {"plot": {}}
     all_files = []
     for plot in ["chromosomes", "local_optima", "segmentation", "summary"]:
         if plot == "summary":
-            cur_file = "%s.pdf" % out_base
+            cur_file = f"{out_base}.pdf"
         else:
-            cur_file = "%s_%s.pdf" % (out_base, plot)
+            cur_file = f"{out_base}_{plot}.pdf"
         if not require_exist or os.path.exists(cur_file):
             out["plot"][plot] = cur_file
             all_files.append(os.path.basename(cur_file))
-    for key, ext in [["hetsummary", ".csv"], ["dnacopy", "_dnacopy.seg"], ["genes", "_genes.csv"],
-                     ["log", ".log"], ["loh", "_loh.csv"], ["rds", ".rds"],
+    for key, ext in [["hetsummary", ".csv"],
+                     ["dnacopy", "_dnacopy.seg"], 
+                     ["genes", "_genes.csv"],
+                     ["log", ".log"], 
+                     ["loh", "_loh.csv"], 
+                     ["rds", ".rds"],
                      ["variants", "_variants.csv"]]:
-        cur_file = "%s%s" % (out_base, ext)
+        cur_file = f"{out_base}{ext}"
         if not require_exist or os.path.exists(cur_file):
             out[key] = cur_file
             all_files.append(os.path.basename(cur_file))
@@ -292,15 +318,14 @@ def _get_header(in_handle):
     return in_handle.readline().strip().split(","), in_handle
 
 def _loh_to_vcf(cur):
-    """Convert LOH output into standardized VCF.
-    """
+    """Convert LOH output into standardized VCF."""
     # PureCN 1.14 outputs segments without informative SNPs, skip those
     # see https://github.com/lima1/PureCN/blob/ed7d10c7ca578bc7d1aabef86893c23ddddf79dc/NEWS#L92-L94
     if cur["C"] == "NA" or cur["M"] == "NA":
         return None
     cn = int(float(cur["C"]))
     minor_cn = int(float(cur["M"]))
-    if cur["type"].find("LOH"):
+    if cur["type"].find("LOH") > -1:
         svtype = "LOH"
     elif cn > 2:
         svtype = "DUP"
@@ -309,9 +334,15 @@ def _loh_to_vcf(cur):
     else:
         svtype = None
     if svtype:
-        info = ["SVTYPE=%s" % svtype, "END=%s" % cur["end"],
-                "SVLEN=%s" % (int(cur["end"]) - int(cur["start"])),
-                "CN=%s" % cn, "MajorCN=%s" % (cn - minor_cn), "MinorCN=%s" % minor_cn]
+        # end could be 100.5
+        start = int(float(cur["start"]))
+        end = int(float(cur["end"]))
+        info = [f"SVTYPE={svtype}", 
+                f"END={end}",
+                f"SVLEN={end-start+1}",
+                f"CN={cn}",
+                f"MajorCN={cn - minor_cn}",
+                f"MinorCN={minor_cn}"]
         return [cur["chr"], cur["start"], ".", "N", "<%s>" % svtype, ".", ".",
                 ";".join(info), "GT", "0/1"]
 
@@ -328,21 +359,27 @@ def process_intervals(data):
     if os.path.exists(ready_file):
         return ready_file
     optimized_bed = basename + ".optimized.bed"
-    rscript = utils.Rscript_cmd("r36")
-    interval_file_r = utils.R_package_script("r36", "PureCN", "extdata/IntervalFile.R")
+    rscript = utils.Rscript_cmd("base")
+    interval_file_r = utils.R_package_script("PureCN", "extdata/IntervalFile.R", env="base")
     ref_file = dd.get_ref_file(data)
     mappability_resource = dd.get_variation_resources(data)["purecn_mappability"]
     genome = dd.get_genome_build(data)
-    cmd = [rscript, interval_file_r, "--infile", bed_file,
+    tools_off = dd.get_tools_off(data)
+    if tools_off and "purecn_offtarget" in tools_off:
+        offtarget_flag = ""
+    else:
+        offtarget_flag = "--off-target"
+    cmd = [rscript, interval_file_r, 
+          "--in-file", bed_file,
           "--fasta", ref_file,
-          "--outfile", ready_file,
-          "--offtarget",
+          "--out-file", ready_file,
+          offtarget_flag,
           "--genome", genome,
           "--export", optimized_bed,
           "--mappability", mappability_resource]
     try:
-        cmd_line = "export R_LIBS_USER=%s && %s && %s" % (utils.R_sitelib(env = "r36"),
-                                                     utils.get_R_exports(env = "r36"),
+        cmd_line = "export R_LIBS_USER=%s && %s && %s" % (utils.R_sitelib(env = "base"),
+                                                     utils.get_R_exports(env = "base"),
                                                      " ".join([str(x) for x in cmd]))
         do.run(cmd_line, "PureCN intervals")
     except subprocess.CalledProcessError as msg:
@@ -358,8 +395,8 @@ def get_coverage(data):
     bed_file = tz.get_in(["config", "algorithm", "purecn_bed_ready"], data)
     sample_name = dd.get_sample_name(data)
     work_dir = _sv_workdir(data)
-    rscript = utils.Rscript_cmd("r36")
-    coverage_r = utils.R_package_script("r36", "PureCN", "extdata/Coverage.R")
+    rscript = utils.Rscript_cmd("base")
+    coverage_r = utils.R_package_script("PureCN", "extdata/Coverage.R", env="base")
     intervals = tz.get_in(["config", "algorithm", "purecn_bed_ready"], data)
     # PureCN resolves symlinks and the actual output PureCN coverage file name
     # is derived from the end bam not from bam_file
@@ -369,12 +406,12 @@ def get_coverage(data):
     result_file = os.path.join(work_dir, bname + "_coverage_loess.txt.gz")
     if not os.path.exists(result_file):
         cmd = [rscript, coverage_r,
-               "--outdir", work_dir,
+               "--out-dir", work_dir,
                "--bam", bam_file,
                "--intervals", intervals]
         try:
-            cmd_line = "export R_LIBS_USER=%s && %s && %s" % (utils.R_sitelib(env = "r36"),
-                                                              utils.get_R_exports(env = "r36"),
+            cmd_line = "export R_LIBS_USER=%s && %s && %s" % (utils.R_sitelib(env = "base"),
+                                                              utils.get_R_exports(env = "base"),
                                                               " ".join([str(x) for x in cmd]))
             do.run(cmd_line, "PureCN coverage")
         except subprocess.CalledProcessError as msg:
@@ -390,17 +427,17 @@ def create_normal_db(coverage_files_txt, snv_pon, out_dir, genome_build):
               mapping_bias_hg38.rds
               normalDB_hg38.rds
     """
-    rscript = utils.Rscript_cmd("r36")
-    normaldb_r = utils.R_package_script("r36", "PureCN", "extdata/NormalDB.R")
+    rscript = utils.Rscript_cmd("base")
+    normaldb_r = utils.R_package_script("PureCN", "extdata/NormalDB.R", env="base")
     cmd = [rscript, normaldb_r,
-           "--outdir", out_dir,
-           "--coveragefiles", coverage_files_txt,
-           "--normal_panel" , snv_pon,
+           "--out-dir", out_dir,
+           "--coverage-files", coverage_files_txt,
+           "--normal-panel" , snv_pon,
            "--genome", genome_build,
            "--force"]
     try:
-        cmd_line = "export R_LIBS_USER=%s && %s && %s" % (utils.R_sitelib(env = "r36"),
-                                                          utils.get_R_exports(env = "r36"),
+        cmd_line = "export R_LIBS_USER=%s && %s && %s" % (utils.R_sitelib(env = "base"),
+                                                          utils.get_R_exports(env = "base"),
                                                           " ".join([str(x) for x in cmd]))
         do.run(cmd_line, "PureCN normalDB")
     except subprocess.CalledProcessError as msg:
