@@ -47,7 +47,14 @@ def get_type(data):
     """Retrieve the type of effects calculation to do.
     """
     if data["analysis"].lower().startswith("var") or dd.get_variantcaller(data):
-        return tz.get_in(("config", "algorithm", "effects"), data, "snpeff")
+        etype = tz.get_in(("config", "algorithm", "effects"), data, "snpeff")
+        if isinstance(etype, (list, tuple)):
+            if len(etype) == 1:
+                return etype[0]
+            else:
+                raise ValueError("Unexpected variant effect type for %s: %s" % (dd.get_sample_name(data), etype))
+        else:
+            return etype
 
 # ## Ensembl VEP
 
@@ -72,7 +79,7 @@ def _special_dbkey_maps(dbkey, ref_file):
 
 
 def prep_vep_cache(dbkey, ref_file, tooldir=None, config=None):
-    """Ensure correct installation of VEP cache file.
+    """VEP cache installation. Called from bcbio/install.py
     """
     if config is None: config = {}
     resource_file = os.path.join(os.path.dirname(ref_file), "%s-resources.yaml" % dbkey)
@@ -96,7 +103,13 @@ def prep_vep_cache(dbkey, ref_file, tooldir=None, config=None):
             if not os.path.exists(out_dir):
                 tmp_dir = utils.safe_makedir(os.path.join(vep_dir, species, "txtmp"))
                 eversion = vepv.split("_")[0]
-                url = "http://ftp.ensembl.org/pub/release-%s/variation/VEP/%s.tar.gz" % (eversion, ensembl_name)
+                if int(eversion) >= 98:
+                    vep_url_string = "indexed_vep_cache"
+                elif int(eversion) == 97:
+                    vep_url_string = "vep"
+                else:
+                    vep_url_string = "VEP"
+                url = "http://ftp.ensembl.org/pub/release-%s/variation/%s/%s.tar.gz" % (eversion, vep_url_string, ensembl_name)
                 with utils.chdir(tmp_dir):
                     subprocess.check_call(["wget", "--no-check-certificate", "-c", url])
                 vep_path = "%s/bin/" % tooldir if tooldir else ""
@@ -116,6 +129,25 @@ def prep_vep_cache(dbkey, ref_file, tooldir=None, config=None):
             return vep_dir, species
     return None, None
 
+def get_vep_cache(dbkey, ref_file, tooldir=None, config=None):
+    """ don't install VEP cache when running bcbio, just return its location
+    """
+    if config is None: config = {}
+    resource_file = os.path.join(os.path.dirname(ref_file), "%s-resources.yaml" % dbkey)
+    if os.path.exists(resource_file):
+        with open(resource_file) as in_handle:
+            resources = yaml.safe_load(in_handle)
+        ensembl_name = tz.get_in(["aliases", "ensembl"], resources)
+        symlink_dir = _special_dbkey_maps(dbkey, ref_file)
+        if symlink_dir and ensembl_name:
+            species, vepv = ensembl_name.split("_vep_")
+            return symlink_dir, species
+        elif ensembl_name:
+            species, vepv = ensembl_name.split("_vep_")
+            vep_dir = os.path.normpath(os.path.join(os.path.dirname(os.path.dirname(ref_file)), "vep"))
+            return vep_dir, species
+    return None, None
+
 def run_vep(in_file, data):
     """Annotate input VCF file with Ensembl variant effect predictor.
     """
@@ -125,7 +157,7 @@ def run_vep(in_file, data):
     assert in_file.endswith(".gz") and out_file.endswith(".gz")
     if not utils.file_exists(out_file):
         with file_transaction(data, out_file) as tx_out_file:
-            vep_dir, ensembl_name = prep_vep_cache(data["genome_build"],
+            vep_dir, ensembl_name = get_vep_cache(data["genome_build"],
                                                    tz.get_in(["reference", "fasta", "base"], data))
             if vep_dir:
                 cores = tz.get_in(("config", "algorithm", "num_cores"), data, 1)
@@ -139,7 +171,8 @@ def run_vep(in_file, data):
                     hgvs_compatible = False
                     config_args = ["--fasta", dd.get_ref_file(data)]
                 if vcfanno.is_human(data):
-                    plugin_fns = {"loftee": _get_loftee, "maxentscan": _get_maxentscan,"genesplicer": _get_genesplicer,
+                    plugin_fns = {"loftee": _get_loftee, "maxentscan": _get_maxentscan,
+                                  "genesplicer": _get_genesplicer,
                                   "spliceregion": _get_spliceregion, "G2P": _get_G2P}
                     plugins = ["loftee", "G2P"]
                     if "vep_splicesite_annotations" in dd.get_tools_on(data):
@@ -148,12 +181,17 @@ def run_vep(in_file, data):
                     for plugin in plugins:
                         plugin_args = plugin_fns[plugin](data)
                         config_args += plugin_args
-                    config_args += ["--sift", "b", "--polyphen", "b"]
+                    config_args += ["--sift", "b", "--polyphen", "b", "--humdiv"]
                     if hgvs_compatible:
-                        config_args += ["--hgvsg","--hgvs", "--shift_hgvs", "1"]
+                        config_args += ["--hgvsg", "--hgvs", "--shift_hgvs", "1"]
                 if (dd.get_effects_transcripts(data).startswith("canonical")
                       or tz.get_in(("config", "algorithm", "clinical_reporting"), data)):
-                    config_args += ["--pick_allele"]
+                    config_args += ["--most_severe"]
+                else:
+                    config_args += ["--flag_pick_allele_gene",
+                                    "--appris", "--biotype", "--canonical",
+                                    "--ccds", "--domains", "--numbers", "--protein",
+                                    "--symbol", "--tsl", "--uniprot"]
                 if ensembl_name.endswith("_merged"):
                     config_args += ["--merged"]
                     ensembl_name = ensembl_name.replace("_merged", "")
@@ -163,9 +201,8 @@ def run_vep(in_file, data):
                       ["--species", ensembl_name,
                        "--no_stats", "--cache",
                         "--offline", "--dir", vep_dir,
-                       "--symbol", "--numbers", "--biotype", "--total_length", "--canonical",
-                       "--gene_phenotype", "--ccds", "--uniprot", "--domains", "--regulatory",
-                       "--protein", "--tsl", "--appris", "--af", "--max_af", "--af_1kg", "--af_esp", "--af_gnomad",
+                       "--total_length", "--gene_phenotype", "--regulatory",
+                        "--af", "--max_af", "--af_1kg", "--af_esp", "--af_gnomad",
                        "--pubmed", "--variant_class", "--allele_number"] + config_args
                 perl_exports = utils.get_perl_exports()
                 # Remove empty fields (';;') which can cause parsing errors downstream
@@ -211,8 +248,9 @@ def _get_genesplicer(data):
 
     genesplicer_exec = os.path.realpath(config_utils.get_program("genesplicer", data["config"]))
     genesplicer_training = tz.get_in(("genome_resources", "variation", "genesplicer"), data)
-    if genesplicer_exec and os.path.exists(genesplicer_exec) and genesplicer_training and os.path.exists(genesplicer_training) :
-        return ["--plugin", "GeneSplicer,%s,%s" % (genesplicer_exec,genesplicer_training)]
+    if (genesplicer_exec and os.path.exists(genesplicer_exec) and genesplicer_training
+            and os.path.exists(genesplicer_training)):
+        return ["--plugin", "GeneSplicer,%s,%s" % (genesplicer_exec, genesplicer_training)]
     else:
         return []
 
