@@ -133,8 +133,7 @@ def _get_system_config(work_dir, system):
 
 @pytest.fixture
 def install_test_files(data_dir):
-    """Download required sequence and reference files.
-    """
+    """Download required sequence and reference files."""
     DlInfo = collections.namedtuple("DlInfo", "fname dirname version")
     download_data = [
         DlInfo("110106_FC70BUKAAXX.tar.gz", None, None),
@@ -145,7 +144,7 @@ def install_test_files(data_dir):
         DlInfo("singlecell-rnaseq-test-data.tar.gz", "Harvard-inDrop", 1)
     ]
     for dl in download_data:
-        url = "http://chapmanb.s3.amazonaws.com/{fname}".format(fname=dl.fname)
+        url = f"https://bcbio-nextgen.s3.amazonaws.com/test_data/{dl.fname}"
         dirname = os.path.join(
             data_dir, os.pardir,
             dl.fname.replace(".tar.gz", "") if dl.dirname is None
